pub struct FileDescriptor { /* private fields */ }Expand description
A handle to a file descriptor within a DescriptorPool.
Implementations
Sourceimpl FileDescriptor
impl FileDescriptor
Sourcepub fn package_name(&self) -> &str
pub fn package_name(&self) -> &str
The protobuf package, e.g. "my.package" (empty if none).
Sourcepub fn dependencies(&self) -> impl Iterator<Item = &str> + '_
pub fn dependencies(&self) -> impl Iterator<Item = &str> + '_
The names of imported (dependency) files.
Sourcepub fn java_package(&self) -> Option<&str>
pub fn java_package(&self) -> Option<&str>
The java_package file option, if set.
Sourcepub fn go_package(&self) -> Option<&str>
pub fn go_package(&self) -> Option<&str>
The go_package file option, if set.
Sourcepub fn java_outer_classname(&self) -> Option<&str>
pub fn java_outer_classname(&self) -> Option<&str>
The java_outer_classname file option, if set.
Sourcepub fn is_deprecated(&self) -> bool
pub fn is_deprecated(&self) -> bool
Returns true if the deprecated file option is set to true.
Sourcepub fn optimize_for(&self) -> i32
pub fn optimize_for(&self) -> i32
The raw optimize_for option value (0 = SPEED, 2 = CODE_SIZE, 3 =
LITE_RUNTIME; 0 is the default when unset).