MethodDescriptor

Struct MethodDescriptor 

pub struct MethodDescriptor { /* private fields */ }
A method definition for a ServiceDescriptor.

Implementations

Source

impl MethodDescriptor

pub fn new(service: ServiceDescriptor, index: usize) -> MethodDescriptor

Create a new MethodDescriptor referencing the method at index within the ServiceDescriptor.

Panics

Panics if index is out-of-bounds.

pub fn index(&self) -> usize

Gets the index of the method within the parent ServiceDescriptor.

pub fn parent_service(&self) -> &ServiceDescriptor

Gets a reference to the ServiceDescriptor this method is defined in.

pub fn parent_pool(&self) -> &DescriptorPool

Gets a reference to the DescriptorPool this method is defined in.

pub fn parent_file(&self) -> FileDescriptor

Gets the FileDescriptor this method is defined in.

pub fn name(&self) -> &str

Gets the short name of the method, e.g. method.

pub fn full_name(&self) -> &str

Gets the full name of the method, e.g. my.package.MyService.my_method.

pub fn path(&self) -> &[i32]

Gets the path where this method is defined within the FileDescriptorProto, e.g. [6, 0, 2, 0].

See path for more details on the structure of the path.

pub fn method_descriptor_proto(&self) -> &MethodDescriptorProto

Gets a reference to the raw MethodDescriptorProto wrapped by this MethodDescriptor.

pub fn options(&self) -> DynamicMessage

Decodes the options defined for this MethodDescriptorProto, including any extension options.

pub fn input(&self) -> MessageDescriptor

Gets the MessageDescriptor for the input type of this method.

pub fn output(&self) -> MessageDescriptor

Gets the MessageDescriptor for the output type of this method.

pub fn is_client_streaming(&self) -> bool

Returns true if the client streams multiple messages.

pub fn is_server_streaming(&self) -> bool

Returns true if the server streams multiple messages.