ServiceDescriptor

Struct ServiceDescriptor 

pub struct ServiceDescriptor { /* private fields */ }
A protobuf service definition.

Implementations

Source

impl ServiceDescriptor

pub fn new(pool: DescriptorPool, index: usize) -> ServiceDescriptor

Create a new ServiceDescriptor referencing the service at index within the given DescriptorPool.

Panics

Panics if index is out-of-bounds.

pub fn index(&self) -> usize

Returns the index of this ServiceDescriptor within the parent DescriptorPool.

pub fn parent_pool(&self) -> &DescriptorPool

Gets a reference to the DescriptorPool this service is defined in.

pub fn parent_file(&self) -> FileDescriptor

Gets the FileDescriptor this service is defined in.

pub fn name(&self) -> &str

Gets the short name of the service, e.g. MyService.

pub fn full_name(&self) -> &str

Gets the full name of the service, e.g. my.package.Service.

pub fn package_name(&self) -> &str

Gets the name of the package this service is defined in, e.g. my.package.

If no package name is set, an empty string is returned.

pub fn path(&self) -> &[i32]

Gets the path where this service is defined within the FileDescriptorProto, e.g. [6, 0].

See path for more details on the structure of the path.

pub fn parent_file_descriptor_proto(&self) -> &FileDescriptorProto

Gets a reference to the FileDescriptorProto in which this service is defined.

pub fn service_descriptor_proto(&self) -> &ServiceDescriptorProto

Gets a reference to the raw ServiceDescriptorProto wrapped by this ServiceDescriptor.

pub fn options(&self) -> DynamicMessage

Decodes the options defined for this ServiceDescriptorProto, including any extension options.

pub fn methods(&self) -> impl ExactSizeIterator

Gets an iterator yielding a MethodDescriptor for each method defined in this service.