MessageDescriptor

Struct MessageDescriptor 

pub struct MessageDescriptor { /* private fields */ }
A protobuf message definition.

Implementations

Source

impl MessageDescriptor

pub fn parent_pool(&self) -> &DescriptorPool

Gets a reference to the DescriptorPool this message is defined in.

pub fn parent_file(&self) -> FileDescriptor

Gets the FileDescriptor this message is defined in.

pub fn parent_message(&self) -> Option<MessageDescriptor>

Gets the parent message type if this message type is nested inside a another message, or None otherwise

pub fn name(&self) -> &str

Gets the short name of the message type, e.g. MyMessage.

pub fn full_name(&self) -> &str

Gets the full name of the message type, e.g. my.package.MyMessage.

pub fn package_name(&self) -> &str

Gets the name of the package this message type is defined in, e.g. my.package.

If no package name is set, an empty string is returned.

pub fn path(&self) -> &[i32]

Gets the path where this message is defined within the FileDescriptorProto, e.g. [4, 0].

See path for more details on the structure of the path.

pub fn parent_file_descriptor_proto(&self) -> &FileDescriptorProto

Gets a reference to the FileDescriptorProto in which this message is defined.

pub fn descriptor_proto(&self) -> &DescriptorProto

Gets a reference to the raw DescriptorProto wrapped by this MessageDescriptor.

pub fn options(&self) -> DynamicMessage

Decodes the options defined for this MessageDescriptor, including any extension options.

pub fn fields(&self) -> impl ExactSizeIterator

Gets an iterator yielding a FieldDescriptor for each field defined in this message.

pub fn oneofs(&self) -> impl ExactSizeIterator

Gets an iterator yielding a OneofDescriptor for each oneof field defined in this message.

pub fn child_messages(&self) -> impl ExactSizeIterator

Gets the nested message types defined within this message.

pub fn child_enums(&self) -> impl ExactSizeIterator

Gets the nested enum types defined within this message.

pub fn child_extensions(&self) -> impl ExactSizeIterator

Gets the nested extension fields defined within this message.

Note this only returns extensions defined nested within this message. See MessageDescriptor::extensions to get fields defined anywhere that extend this message.

pub fn extensions(&self) -> impl ExactSizeIterator

Gets an iterator over all extensions to this message defined in the parent DescriptorPool.

Note this iterates over extension fields defined anywhere which extend this message. See MessageDescriptor::child_extensions to just get extensions defined nested within this message.

pub fn get_field(&self, number: u32) -> Option<FieldDescriptor>

Gets a FieldDescriptor with the given number, or None if no such field exists.

pub fn get_field_by_name(&self, name: &str) -> Option<FieldDescriptor>

Gets a FieldDescriptor with the given name, or None if no such field exists.

pub fn get_field_by_json_name(&self, json_name: &str) -> Option<FieldDescriptor>

Gets a FieldDescriptor with the given JSON name, or None if no such field exists.

pub fn is_map_entry(&self) -> bool

Returns true if this is an auto-generated message type to represent the entry type for a map field. If this method returns true, fields is guaranteed to yield the following two fields:

  • A “key” field with a field number of 1
  • A “value” field with a field number of 2

See map_entry_key_field and map_entry_value_field for more a convenient way to get these fields.

pub fn map_entry_key_field(&self) -> FieldDescriptor

If this is a map entry, returns a FieldDescriptor for the key.

Panics

This method may panic if is_map_entry returns false.

pub fn map_entry_value_field(&self) -> FieldDescriptor

If this is a map entry, returns a FieldDescriptor for the value.

Panics

This method may panic if is_map_entry returns false.

pub fn reserved_ranges(&self) -> impl ExactSizeIterator

Gets an iterator over reserved field number ranges in this message.

pub fn reserved_names(&self) -> impl ExactSizeIterator

Gets an iterator over reserved field names in this message.

pub fn extension_ranges(&self) -> impl ExactSizeIterator

Gets an iterator over extension field number ranges in this message.

pub fn get_extension(&self, number: u32) -> Option<ExtensionDescriptor>

Gets an extension to this message by its number, or None if no such extension exists.

pub fn get_extension_by_full_name( &self, name: &str, ) -> Option<ExtensionDescriptor>

Gets an extension to this message by its full name (e.g. my.package.my_extension), or None if no such extension exists.

pub fn get_extension_by_json_name( &self, name: &str, ) -> Option<ExtensionDescriptor>

Gets an extension to this message by its JSON name (e.g. [my.package.my_extension]), or None if no such extension exists.